A vector of times, the same length as the number of points in pts.
poly
A polygon enclosing the points.
tlimits
A vector of length 2, specifying the upper and lower temporal domain.
s
A vector of spatial distances for the analysis.
tt
A vector of times for the analysis.
nsim
The number of simulations to do.
quiet
If quiet=T then no output is produced, otherwise the function
prints the number of simulations completed so far, and also how the
test statistic for the data ranks with the simulations.
Value
A vector of length nsim+1. The first element is the test statistic
for the data, and the remaining elements are those for the simulations.
Details
The function uses a sum of residuals as a test statistic,
randomly permutes the times of the set of points and recomputes the
test statistic for a number of simulations.
See Diggle, Chetwynd, Haggkvist and Morris (1995) for details.
References
Diggle, P., Chetwynd, A., Haggkvist, R. and Morris, S. 1995 Second-order analysis of space-time clustering. Statistical Methods in Medical Research, 4, 124-136;Bailey, T. C. and Gatrell, A. C. 1995, Interactive spatial data analysis. Longman, Harlow, pp. 122-125;
Rowlingson, B. and Diggle, P. 1993 Splancs: spatial point pattern analysis
code in S-Plus. Computers and Geosciences, 19, 627-655;
the original sources can be accessed at:
http://www.maths.lancs.ac.uk/~rowlings/Splancs/. See also Bivand, R. and
Gebhardt, A. 2000 Implementing functions for spatial statistical analysis
using the R language. Journal of Geographical Systems, 2, 307-317.